@@ -63,7 +63,7 @@ class ImportMatrixXls(ImportMatrix):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -138,9 +138,11 @@ class ImportMatrixXls(ImportMatrix):
             return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -159,6 +161,8 @@ class ImportMatrixXls(ImportMatrix):
             diff_list.append(name + ".axes_colrows")
         if other._is_allsheets != self._is_allsheets:
             diff_list.append(name + ".is_allsheets")
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
@@ -279,7 +283,7 @@ class ImportMatrixXls(ImportMatrix):
     usecols = property(
         fget=_get_usecols,
         fset=_set_usecols,
-        doc=u"""To select the range of column to use
+        doc=u"""list of Excel column letters and column ranges (e.g. "A:E" or "A,C,E:F")
 
         :Type: str
         """,
