@@ -68,6 +68,7 @@ from .Winding import Winding
 from .Slot import Slot
 from .Hole import Hole
 from .Notch import Notch
+from .Bore import Bore
 
 
 class LamSquirrelCage(LamSlotWind):
@@ -192,13 +193,14 @@ class LamSquirrelCage(LamSlotWind):
         axial_vent=-1,
         notch=-1,
         yoke_notch=-1,
+        bore=None,
         init_dict=None,
         init_str=None,
     ):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -246,6 +248,8 @@ class LamSquirrelCage(LamSlotWind):
                 notch = init_dict["notch"]
             if "yoke_notch" in list(init_dict.keys()):
                 yoke_notch = init_dict["yoke_notch"]
+            if "bore" in list(init_dict.keys()):
+                bore = init_dict["bore"]
         # Set the properties (value check and convertion are done in setter)
         self.Hscr = Hscr
         self.Lscr = Lscr
@@ -267,6 +271,7 @@ class LamSquirrelCage(LamSlotWind):
             axial_vent=axial_vent,
             notch=notch,
             yoke_notch=yoke_notch,
+            bore=bore,
         )
         # The class is frozen (in LamSlotWind init), for now it's impossible to
         # add new properties
@@ -303,9 +308,11 @@ class LamSquirrelCage(LamSlotWind):
             return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -324,6 +331,8 @@ class LamSquirrelCage(LamSlotWind):
             diff_list.extend(
                 self.ring_mat.compare(other.ring_mat, name=name + ".ring_mat")
             )
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
