@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QWidget
+from PySide2.QtCore import Signal
+from PySide2.QtWidgets import QWidget
 
 from .......GUI import gui_option
 from .......GUI.Dialog.DMachineSetup.SLamParam.DAVDuct.PVentPolar.Gen_PVentPolar import (
@@ -10,11 +10,10 @@ from .......GUI.Dialog.DMachineSetup.SLamParam.DAVDuct.PVentPolar.Gen_PVentPolar
 
 
 class PVentPolar(Gen_PVentPolar, QWidget):
-    """Page to setup the Ventilation Polar
-    """
+    """Page to setup the Ventilation Polar"""
 
     # Signal to DMachineSetup to know that the save popup is needed
-    saveNeeded = pyqtSignal()
+    saveNeeded = Signal()
 
     def __init__(self, lam=None, vent=None):
         """Initialize the widget according the current lamination
@@ -55,7 +54,7 @@ class PVentPolar(Gen_PVentPolar, QWidget):
         # Set unit name (m ou mm)
         wid_list = [self.unit_H0, self.unit_D0]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
 
         # Connect the signal
         self.si_Zh.editingFinished.connect(self.set_Zh)
@@ -125,7 +124,7 @@ class PVentPolar(Gen_PVentPolar, QWidget):
         Parameters
         ----------
         self : PVentPolar
-            A PVentPolar object    
+            A PVentPolar object
 
         Returns
         -------
