@@ -10,10 +10,8 @@ from ......Functions.load import load
 from ......Classes.SlotUD import SlotUD
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlotUD.Ui_PWSlotUD import Ui_PWSlotUD
-from ......GUI.Dialog.DMatLib.MatLib import MatLib
 from ......Methods.Slot.Slot import SlotCheckError
 from ......GUI.Dxf.DXF_Slot import DXF_Slot
-from ......GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
 
 
 class PWSlotUD(Ui_PWSlotUD, QWidget):
