@@ -33,96 +33,101 @@ class Ui_PCondType12(object):
 
         self.horizontalLayout.addWidget(self.img_cond)
 
-        self.widget = QWidget(PCondType12)
-        self.widget.setObjectName(u"widget")
-        self.widget.setMinimumSize(QSize(250, 0))
-        self.widget.setMaximumSize(QSize(250, 16777215))
-        self.verticalLayout = QVBoxLayout(self.widget)
+        self.scrollArea = QScrollArea(PCondType12)
+        self.scrollArea.setObjectName(u"scrollArea")
+        self.scrollArea.setMinimumSize(QSize(270, 0))
+        self.scrollArea.setMaximumSize(QSize(270, 16777215))
+        self.scrollArea.setWidgetResizable(True)
+        self.scrollAreaWidgetContents = QWidget()
+        self.scrollAreaWidgetContents.setObjectName(u"scrollAreaWidgetContents")
+        self.scrollAreaWidgetContents.setGeometry(QRect(0, 0, 268, 648))
+        self.verticalLayout = QVBoxLayout(self.scrollAreaWidgetContents)
         self.verticalLayout.setObjectName(u"verticalLayout")
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_Nwpc1 = QLabel(self.widget)
+        self.in_Nwpc1 = QLabel(self.scrollAreaWidgetContents)
         self.in_Nwpc1.setObjectName(u"in_Nwpc1")
-        self.in_Nwpc1.setMinimumSize(QSize(70, 0))
+        self.in_Nwpc1.setMinimumSize(QSize(90, 0))
 
         self.gridLayout.addWidget(self.in_Nwpc1, 0, 0, 1, 1)
 
-        self.si_Nwpc1 = QSpinBox(self.widget)
+        self.si_Nwpc1 = QSpinBox(self.scrollAreaWidgetContents)
         self.si_Nwpc1.setObjectName(u"si_Nwpc1")
         self.si_Nwpc1.setMinimumSize(QSize(0, 0))
         self.si_Nwpc1.setValue(99)
 
         self.gridLayout.addWidget(self.si_Nwpc1, 0, 1, 1, 1)
 
-        self.in_Wwire = QLabel(self.widget)
+        self.in_Wwire = QLabel(self.scrollAreaWidgetContents)
         self.in_Wwire.setObjectName(u"in_Wwire")
-        self.in_Wwire.setMinimumSize(QSize(70, 0))
+        self.in_Wwire.setMinimumSize(QSize(90, 0))
 
         self.gridLayout.addWidget(self.in_Wwire, 1, 0, 1, 1)
 
-        self.lf_Wwire = FloatEdit(self.widget)
+        self.lf_Wwire = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_Wwire.setObjectName(u"lf_Wwire")
         self.lf_Wwire.setMinimumSize(QSize(0, 0))
         self.lf_Wwire.setMaximumSize(QSize(16777215, 16777215))
 
         self.gridLayout.addWidget(self.lf_Wwire, 1, 1, 1, 1)
 
-        self.unit_Wwire = QLabel(self.widget)
+        self.unit_Wwire = QLabel(self.scrollAreaWidgetContents)
         self.unit_Wwire.setObjectName(u"unit_Wwire")
         self.unit_Wwire.setMinimumSize(QSize(0, 0))
 
         self.gridLayout.addWidget(self.unit_Wwire, 1, 2, 1, 1)
 
-        self.in_Wins_wire = QLabel(self.widget)
+        self.in_Wins_wire = QLabel(self.scrollAreaWidgetContents)
         self.in_Wins_wire.setObjectName(u"in_Wins_wire")
-        self.in_Wins_wire.setMinimumSize(QSize(40, 0))
+        self.in_Wins_wire.setMinimumSize(QSize(90, 0))
 
         self.gridLayout.addWidget(self.in_Wins_wire, 2, 0, 1, 1)
 
-        self.lf_Wins_wire = FloatEdit(self.widget)
+        self.lf_Wins_wire = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_Wins_wire.setObjectName(u"lf_Wins_wire")
         self.lf_Wins_wire.setMinimumSize(QSize(50, 0))
         self.lf_Wins_wire.setMaximumSize(QSize(16777215, 16777215))
 
         self.gridLayout.addWidget(self.lf_Wins_wire, 2, 1, 1, 1)
 
-        self.unit_Wins_wire = QLabel(self.widget)
+        self.unit_Wins_wire = QLabel(self.scrollAreaWidgetContents)
         self.unit_Wins_wire.setObjectName(u"unit_Wins_wire")
         self.unit_Wins_wire.setMinimumSize(QSize(0, 0))
 
         self.gridLayout.addWidget(self.unit_Wins_wire, 2, 2, 1, 1)
 
-        self.in_Wins_cond = QLabel(self.widget)
+        self.in_Wins_cond = QLabel(self.scrollAreaWidgetContents)
         self.in_Wins_cond.setObjectName(u"in_Wins_cond")
+        self.in_Wins_cond.setMinimumSize(QSize(90, 0))
 
         self.gridLayout.addWidget(self.in_Wins_cond, 3, 0, 1, 1)
 
-        self.lf_Wins_cond = FloatEdit(self.widget)
+        self.lf_Wins_cond = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_Wins_cond.setObjectName(u"lf_Wins_cond")
         self.lf_Wins_cond.setMinimumSize(QSize(50, 0))
         self.lf_Wins_cond.setMaximumSize(QSize(16777215, 16777215))
 
         self.gridLayout.addWidget(self.lf_Wins_cond, 3, 1, 1, 1)
 
-        self.unit_Wins_cond = QLabel(self.widget)
+        self.unit_Wins_cond = QLabel(self.scrollAreaWidgetContents)
         self.unit_Wins_cond.setObjectName(u"unit_Wins_cond")
 
         self.gridLayout.addWidget(self.unit_Wins_cond, 3, 2, 1, 1)
 
-        self.in_Lewout = QLabel(self.widget)
+        self.in_Lewout = QLabel(self.scrollAreaWidgetContents)
         self.in_Lewout.setObjectName(u"in_Lewout")
-        self.in_Lewout.setMinimumSize(QSize(40, 0))
+        self.in_Lewout.setMinimumSize(QSize(90, 0))
 
         self.gridLayout.addWidget(self.in_Lewout, 4, 0, 1, 1)
 
-        self.lf_Lewout = FloatEdit(self.widget)
+        self.lf_Lewout = FloatEdit(self.scrollAreaWidgetContents)
         self.lf_Lewout.setObjectName(u"lf_Lewout")
         self.lf_Lewout.setMinimumSize(QSize(50, 0))
         self.lf_Lewout.setMaximumSize(QSize(16777215, 16777215))
 
         self.gridLayout.addWidget(self.lf_Lewout, 4, 1, 1, 1)
 
-        self.unit_Lewout = QLabel(self.widget)
+        self.unit_Lewout = QLabel(self.scrollAreaWidgetContents)
         self.unit_Lewout.setObjectName(u"unit_Lewout")
         self.unit_Lewout.setMinimumSize(QSize(0, 0))
 
@@ -136,12 +141,14 @@ class Ui_PCondType12(object):
 
         self.verticalLayout.addItem(self.verticalSpacer)
 
-        self.w_out = WCondOut(self.widget)
+        self.w_out = WCondOut(self.scrollAreaWidgetContents)
         self.w_out.setObjectName(u"w_out")
 
         self.verticalLayout.addWidget(self.w_out)
 
-        self.horizontalLayout.addWidget(self.widget)
+        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+
+        self.horizontalLayout.addWidget(self.scrollArea)
 
         QWidget.setTabOrder(self.si_Nwpc1, self.lf_Wwire)
         QWidget.setTabOrder(self.lf_Wwire, self.lf_Wins_wire)
