@@ -2,7 +2,7 @@
 
 from matplotlib.patches import Patch
 from matplotlib.pyplot import axis, legend
-
+import matplotlib.pyplot as plt
 from ....Functions.init_fig import init_fig
 from ....definitions import config_dict
 
@@ -21,6 +21,7 @@ def plot(
     delta=0,
     is_edge_only=False,
     is_show_fig=True,
+    win_title=None,
 ):
     """Plot a Lamination with Magnets in a matplotlib fig
 
@@ -44,6 +45,8 @@ def plot(
         To plot transparent Patches
     is_show_fig : bool
         To call show at the end of the method
+    win_title : str
+        Window title
 
     Returns
     -------
@@ -51,8 +54,10 @@ def plot(
     """
 
     if self.is_stator:
+        Lam_Name = "Stator"
         lam_color = STATOR_COLOR
     else:
+        Lam_Name = "Rotor"
         lam_color = ROTOR_COLOR
 
     (fig, axes, patch_leg, label_leg) = init_fig(fig=fig, ax=ax, shape="rectangle")
@@ -85,6 +90,19 @@ def plot(
     axes.set_xlim(-Lim, Lim)
     axes.set_ylim(-Lim, Lim)
 
+    # Window title
+    if (
+        win_title is None
+        and self.parent is not None
+        and self.parent.name not in [None, ""]
+    ):
+        win_title = self.parent.name + " " + Lam_Name
+    elif win_title is None:
+        win_title = Lam_Name
+    manager = plt.get_current_fig_manager()
+    if manager is not None:
+        manager.set_window_title(win_title)
+
     # Add the legend
     if not is_edge_only:
         if self.is_stator:
