@@ -1,9 +1,10 @@
 from ....Functions.Geometry.merge_notch_list import merge_notch_list
 from ....Classes.Arc1 import Arc1
 from numpy import exp, pi
+from ....Classes.Lamination import Lamination
 
 
-def get_bore_desc(self, sym=1):
+def get_bore_desc(self, sym=1, line_label=None):
     """This method returns an ordered description of the elements
     that defines the bore radius of the lamination
 
@@ -11,23 +12,32 @@ def get_bore_desc(self, sym=1):
     ----------
     self : LamSlotMulti
         A LamSlotMulti object
+    line_label : str
+        Label to apply on the lines
 
     Returns
     -------
     bore_desc : list
         list of dictionary with key: "begin_angle", "end_angle", "obj"
+    bore_line : list
+        list of lines to draw the bore radius
     """
 
+    if self.slot_list is None:  # No slot
+        return Lamination.get_bore_desc(self, sym=sym, line_label=line_label)
+
     Rbo = self.get_Rbo()
     slot_list = list()
     # First add all the slots
     for ii in range(len(self.slot_list) // sym):
         slot = self.slot_list[ii]
         op = slot.comp_angle_opening()
+        lines = slot.build_geometry()
         bore_dict = dict()
         bore_dict["begin_angle"] = self.alpha[ii] - op / 2
         bore_dict["end_angle"] = self.alpha[ii] + op / 2
         bore_dict["obj"] = slot
+        bore_dict["lines"] = lines
         slot_list.append(bore_dict)
 
     # Get the notches
@@ -93,4 +103,25 @@ def get_bore_desc(self, sym=1):
             is_trigo_direction=True,
         )
         bore_desc.insert(0, bore_dict)
-    return bore_desc
+
+    # Convert the description to lines
+    bore_lines = list()
+    for bore in bore_desc:
+        if isinstance(bore["obj"], Arc1):
+            bore_lines.append(bore["obj"])
+        elif "lines" in bore:  # Duplicated slot
+            for line in bore["lines"]:
+                bore_lines.append(line.copy())
+                bore_lines[-1].rotate((bore["begin_angle"] + bore["end_angle"]) / 2)
+        else:  # Notches
+            lines = bore["obj"].build_geometry()
+            for line in lines:
+                line.rotate((bore["begin_angle"] + bore["end_angle"]) / 2)
+            bore_lines.extend(lines)
+
+    # Set line label
+    if line_label is not None:
+        for line in bore_lines:
+            line.label = line_label
+
+    return bore_desc, bore_lines
