@@ -133,7 +133,7 @@ def solve_FEA(self, output, sym, angle, time, angle_rotor, Is, Ir):
 
     elmer_sim_file = join(project_name, "pyleecan_elmer.sif")
     pp = machine.stator.winding.p
-    wind_mat = machine.stator.winding.comp_connection_mat(machine.stator.slot.Zs)
+    wind_mat = machine.stator.winding.get_connection_mat(machine.stator.slot.Zs)
     surf_wind = machine.stator.slot.comp_surface_active()
     ror = machine.rotor.comp_radius_mec()
     sir = machine.stator.comp_radius_mec()
@@ -170,7 +170,7 @@ def solve_FEA(self, output, sym, angle, time, angle_rotor, Is, Ir):
         Ncond_Eminus = 1
         Ncond_Fplus = 1
         Ncond_Fminus = 1
-        Npcpp = machine.stator.winding.Npcpp
+        Npcp = machine.stator.winding.Npcp
         for surf in surf_list:
             label = surface_label.get(surf.label, "UNKNOWN")
             if "H_MAGNET" in label:  # LamHole
