@@ -14,13 +14,11 @@ try:  # Import if pyleecan is installed with pip
     from .definitions import ROOT_DIR, PACKAGE_NAME, config_dict
     from .GUI.Dialog.DMachineSetup.DMachineSetup import DMachineSetup
     from .GUI.Dialog.DMatLib.DMatLib import DMatLib
-    from .GUI.Dialog.DMatLib.MatLib import MatLib
-    from .GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect
     from .GUI.Tools.SidebarWindow import SidebarWindow
     from .GUI.Tools.MachinePlotWidget import MachinePlotWidget
     from .GUI.Tools.TreeView import TreeView
     from .GUI.Tools.GuiOption.WGuiOption import WGuiOption
-
+    from .Functions.load import load_matlib
 except ImportError:  # Import for dev version
     from definitions import PACKAGE_NAME, ROOT_DIR, config_dict
 
@@ -30,18 +28,13 @@ except ImportError:  # Import for dev version
         + ".GUI.Dialog.DMachineSetup.DMachineSetup import DMachineSetup"
     )
     exec("from " + PACKAGE_NAME + ".GUI.Dialog.DMatLib.DMatLib import DMatLib")
-    exec("from " + PACKAGE_NAME + ".GUI.Dialog.DMatLib.MatLib import MatLib")
-    exec(
-        "from "
-        + PACKAGE_NAME
-        + ".GUI.Dialog.DMatLib.WMatSelect.WMatSelect import WMatSelect"
-    )
     exec("from " + PACKAGE_NAME + ".GUI.Tools.SidebarWindow import SidebarWindow")
     exec(
         "from " + PACKAGE_NAME + ".GUI.Tools.MachinePlotWidget import MachinePlotWidget"
     )
     exec("from " + PACKAGE_NAME + ".GUI.Tools.TreeView import TreeView")
     exec("from " + PACKAGE_NAME + ".GUI.Tools.GuiOption.WGuiOption import WGuiOption")
+    exec("from " + PACKAGE_NAME + ".Functions.load import load_matlib")
 
 
 EXT_GUI = True
@@ -65,15 +58,17 @@ def run_GUI(argv):
         with open(config_dict["GUI"]["CSS_PATH"], "r") as css_file:
             a.setStyleSheet(css_file.read())
 
-    # Setting the material library
-    matlib = MatLib(config_dict["MAIN"]["MATLIB_DIR"])
+    # Load Material Library
+    material_dict = load_matlib(
+        machine=None, matlib_path=config_dict["MAIN"]["MATLIB_DIR"]
+    )
 
     # MatLib widget
-    mat_widget = DMatLib(matlib, selected=0)
+    mat_widget = DMatLib(material_dict=material_dict)
 
     # Machine Setup Widget
     c = DMachineSetup(
-        dmatlib=mat_widget, machine_path=config_dict["MAIN"]["MACHINE_DIR"]
+        material_dict=material_dict, machine_path=config_dict["MAIN"]["MACHINE_DIR"]
     )
 
     if EXT_GUI:
@@ -96,7 +91,7 @@ def run_GUI(argv):
         tree_fcn = lambda: tree.generate(getattr(c, "machine"))
         window.addSubWindow("TreeView", tree, tree_fcn)
 
-        option = WGuiOption(machine_setup=c, matlib=matlib)
+        option = WGuiOption(machine_setup=c, matlib=mat_widget)
         window.addSubWindow("Option", option)
         window.show()
 
